@@ -9,19 +9,7 @@ use Carp qw(croak);
 use Fcntl qw(LOCK_EX LOCK_NB);
 use English qw(-no_match_vars);
 
-our $VERSION = '0.06';
-
-sub is_locked {
-    my ($self) = @ARG;
-
-    return $self->{'is_locked'};
-}
-
-sub lock_file {
-    my ($self) = @ARG;
-
-    return $self->{'lock_file'};
-}
+our $VERSION = '0.061';
 
 sub new {
     my ($class, %param) = @ARG;
@@ -41,13 +29,32 @@ sub new {
     return bless(
         {
             is_locked => 0,
-            lock_file => $lock_file,
             fh        => undef,
+            error     => undef,
+            lock_file => $lock_file,
         },
         $class,
     );
 }
 
+sub is_locked {
+    my ($self) = @ARG;
+
+    return $self->{'is_locked'};
+}
+
+sub lock_file {
+    my ($self) = @ARG;
+
+    return $self->{'lock_file'};
+}
+
+sub error {
+    my ($self) = @ARG;
+
+    return $self->{'error'};
+}
+
 # Lock or raise an exception
 sub lock {
     my ($self) = @ARG;
@@ -73,7 +80,9 @@ sub unlock {
     $self->_set_fh(undef);
 
     if (!unlink $self->lock_file) {
-        croak sprintf(q{Can't unlink "%s": %s}, $self->lock_file, $OS_ERROR);
+        $self->_set_error($OS_ERROR);
+
+        croak sprintf(q{Can't unlink "%s": %s}, $self->lock_file, $self->error);
     }
 
     return $self->_set_is_locked(0);
@@ -126,7 +135,13 @@ sub DESTROY {
 sub _init_file_handle {
     my ($self) = @ARG;
 
-    return IO::File->new($self->lock_file, O_RDWR | O_CREAT);
+    my $fh = IO::File->new($self->lock_file, O_RDWR | O_CREAT);
+
+    if (!$fh) {
+        $self->_set_error($OS_ERROR);
+    }
+
+    return $fh;
 }
 
 sub _lock {
@@ -138,25 +153,29 @@ sub _lock {
     my $fh = $self->_init_file_handle;
 
     if (!$fh) {
-        return if $param{'try'};
-
-        croak sprintf(q{Can't open "%s": %s}, $self->lock_file, $OS_ERROR);
+        croak sprintf(q{Can't open "%s": %s}, $self->lock_file, $self->error);
     }
 
     if (!flock $fh, LOCK_EX | LOCK_NB) {
+        $self->_set_error($OS_ERROR);
+
         return if $param{'try'};
 
-        croak sprintf(q{Can't lock "%s": %s}, $self->lock_file, $OS_ERROR);
+        croak sprintf(q{Can't lock "%s": %s}, $self->lock_file, $self->error);
     }
 
     if (!truncate $fh, 0) {
-        croak sprintf(q{Can't truncate "%s": %s}, $self->lock_file, $OS_ERROR);
+        $self->_set_error($OS_ERROR);
+
+        croak sprintf(q{Can't truncate "%s": %s}, $self->lock_file, $self->error);
     }
 
     autoflush $fh 1;
 
     if (!$fh->print($self->_lock_message)) {
-        croak sprintf(q{Can't write message to file: %s}, $OS_ERROR);
+        $self->_set_error($OS_ERROR);
+
+        croak sprintf(q{Can't write message to file: %s}, $self->error);
     }
 
     return $self->_set_fh($fh)->_set_is_locked(1);
@@ -178,14 +197,6 @@ sub _set_is_locked {
     return $self;
 }
 
-sub _set_lock_file {
-    my ($self, $lock_file) = @ARG;
-
-    $self->{'lock_file'} = $lock_file;
-
-    return $self;
-}
-
 sub _fh {
     my ($self) = @ARG;
 
@@ -200,6 +211,14 @@ sub _set_fh {
     return $self;
 }
 
+sub _set_error {
+    my ($self, $error) = @ARG;
+
+    $self->{'error'} = $error || '<unknown_error>';
+
+    return $self;
+}
+
 1;
 
 __END__
@@ -210,7 +229,7 @@ JIP::LockFile - application lock/mutex based on files
 
 =head1 VERSION
 
-This document describes C<JIP::LockFile> version C<0.06>.
+This document describes C<JIP::LockFile> version C<0.061>.
 
 =head1 SYNOPSIS
 
@@ -219,7 +238,7 @@ This document describes C<JIP::LockFile> version C<0.06>.
     my $lock_file = '/path/to/pid_file';
 
     my $foo = JIP::LockFile->new(lock_file => $lock_file);
-    my $wtf = JIP::LockFile->new(lock_file => $lock_file);
+    my $wtf = JIP::LockFile->new(lock_file => $foo->lock_file);
 
     $foo->lock;           # lock
     eval { $wtf->lock; }; # or raise exception
@@ -247,6 +266,34 @@ This document describes C<JIP::LockFile> version C<0.06>.
     # ... or unlocking is automatic on scope exit
     undef $foo;
 
+=head1 ATTRIBUTES
+
+L<JIP::LockFile> implements the following attributes.
+
+=head2 lock_file
+
+    my $object = JIP::LockFile->new(lock_file => '/path/to/pid_file');
+
+    $object->lock_file; # /path/to/pid_file
+
+=head2 is_locked
+
+    my $object = JIP::LockFile->new(lock_file => '/path/to/pid_file');
+
+    $object->is_locked; # 0
+
+    $object->lock->is_locked; # 1
+
+=head2 error
+
+    my $object = JIP::LockFile->new(lock_file => '/path/to/pid_file');
+
+    $object->lock;
+
+    my $concurrent = JIP::LockFile->new(lock_file => $object->lock_file);
+
+    $concurrent->try_lock->error; # Resource temporarily unavailable
+
 =head1 SEE ALSO
 
 L<Lock::File>, L<Lock::Socket> and L<JIP::LockSocket>.
